%define with_python2 1
%define with_python3 1

Name:           satyr
Version:        0.27
Release:        5
Summary:        Tools to create anonymous, machine-friendly problem reports
License:        GPLv2+
URL:            https://github.com/abrt/satyr
Source0:        https://github.com/abrt/%{name}/archive/%{version}/%{name}-%{version}.tar.gz

Patch9001:      use-python2-explicitly-in-configure.patch

BuildRequires:  elfutils-devel elfutils-libelf-devel binutils-devel rpm-devel libtool
BuildRequires:  doxygen pkgconfig automake gcc-c++ gdb git

%if %{with_python2}
BuildRequires:  python2-devel python2-sphinx 
%endif

%if %{with_python3}
BuildRequires:  python3-devel python3-sphinx
%endif

%description
Satyr is a collection of low-level algorithms for program failure processing,
analysis, and reporting supporting kernel space, user space, Python, and Java
programs.  Considering failure processing, it allows to parse failure
description from various sources such as GDB-created stack traces, Python stack
traces with a description of uncaught exception, and kernel oops message.
Information can also be extracted from the core dumps of unexpectedly
terminated user space processes and from the machine executable code of
binaries.  Considering failure analysis, the stack traces of failed processes
can be normalized, trimmed, and compared.  Clusters of similar stack traces can
be calculated.  In multi-threaded stack traces, the threads that caused the
failure can be discovered.  Considering failure reporting, the library can
generate a failure report in a well-specified format, and the report can be
sent to a remote machine.

%package        devel
Summary:        Header files for satyr
Requires:       %{name} = %{version}-%{release}

%description    devel
Header files for satyr.

%if %{with_python2}
%package     -n python2-satyr
Summary:        python2 for satyr
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-python = %{version}-%{release} 
Provides:       %{name}-python%{?_isa} = %{version}-%{release}
Obsoletes:      %{name}-python < 0.24
%{?python_provide:%python_provide python2-satyr}

%description -n python2-satyr
python2 for satyr
%endif

%if %{with_python3}
%package     -n python3-satyr
Summary:        python3 for satyr
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-python3 = %{version}-%{release}
Provides:       %{name}-python3%{?_isa} = %{version}-%{release}
Obsoletes:      %{name}-python3 < 0.24
%{?python_provide:%python_provide python3-satyr}

%description -n python3-satyr
python3 for satyr
%endif

%package_help

%prep
%define __scm_apply_git(qp:m:) %{__git} am
%autosetup -n %{name}-%{version} -p1

%build
./autogen.sh
%configure  --enable-doxygen-docs

%make_build

%install
%make_install
%delete_la
    
%check
make check|| {
     find tests/testsuite.dir -name "testsuite.log" -print -exec cat '{}' \;
     exit 1
}

%ldconfig_scriptlets

%files
%defattr(-,root,root)
%license COPYING
%{_bindir}/satyr
%{_libdir}/lib*.so.*

%files          devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*

%if %{with_python2}
%files       -n python2-satyr
%{python2_sitearch}/*
%endif

%if %{with_python3}
%files       -n python3-satyr
%{python3_sitearch}/*
%endif

%files           help
%defattr(-,root,root)
%doc README NEWS
%{_mandir}/*

%changelog
* Fri Feb 28 2020 hexiujun <hexiujun1@huawei.com> - 0.27-5
- Type:enhancement
- Id:NA
- SUG:NA
- DESC:use python2 explicitly in configure

* Wed Jan 22 2020 openEuler Buildteam <buildteam@openeuler.org> - 0.27-4
- Type:bugfix
- Id:NA
- SUG:NA
- DESC:add the definition of with_python2 and with_python3

* Tue Dec 31 2019 openEuler Buildteam <buildteam@openeuler.org> - 0.27-3
- Type:bugfix
- ID:NA
- SUG:NA
- DESC:optimization

* Fri Oct 11 2019 openEuler Buildteam <buildteam@openeuler.org> - 0.27-2
- Package init
